@@ -1,5 +1,5 @@
 /* jpnevulator - serial reader/writer
- * Copyright (C) 2006-2014 Freddy Spierenburg
+ * Copyright (C) 2006-2015 Freddy Spierenburg
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,20 @@ enum byteRtrn {
 	byteRtrnUnknown
 };
 
-extern int byteGet(FILE *);
+#define BASES \
+	base2 \
+	base16
+
+#define base2 BASE(2,byteBaseBinary,8)
+#define base16 BASE(16,byteBaseHexadecimal,2)
+
+enum byteBase {
+#define BASE(base,name,width) name=base,
+	BASES
+#undef BASE
+};
+
+extern int byteGet(FILE *,enum byteBase);
+extern void bytePut(FILE *,enum byteBase,unsigned char);
 
 #endif
