@@ -1,5 +1,5 @@
 /* jpnevulator - serial reader/writer
- * Copyright (C) 2006-2014 Freddy Spierenburg
+ * Copyright (C) 2006-2015 Freddy Spierenburg
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,8 @@
 #include <string.h>
 #include <unistd.h>
 #include <sys/time.h>
+#include <sys/types.h>
+#include <sys/stat.h>
 #include <time.h>
 #include <ctype.h>
 
@@ -108,7 +110,7 @@ enum jpnevulatorRtrn jpnevulatorWrite(void) {
 	   this special remark. Not too many details, since I like to keep myself puzzeled
 	   every once in a while. ;) */
 	line=1;
-	for(index=0;(boolIsSet(writingStart)||(_jpnevulatorOptions.count!=0))&&((byte=byteGet(input))!=byteRtrnEOF);) {
+	for(index=0;(boolIsSet(writingStart)||(_jpnevulatorOptions.count!=0))&&((byte=byteGet(input,_jpnevulatorOptions.base))!=byteRtrnEOF);) {
 		if(boolIsSet(writingStart)) {
 			byte=byteRtrnEOL;
 		}
@@ -208,7 +210,15 @@ static void asciiWrite(FILE *output,char *ascii,int asciiSize,int *bytesWritten,
 			if(boolIsSet(fill)) {
 				int index;
 				for(index=*bytesWritten;index<_jpnevulatorOptions.width;index++) {
-					fprintf(output,"   ");
+					switch(_jpnevulatorOptions.base) {
+#define BASE(base,name,width) \
+						case name: { \
+							fprintf(output,"%s",SPACES(width+1)); \
+							break; \
+						}
+						BASES
+#undef BASE
+					}
 				}
 			}
 			fprintf(output,"\t%s",ascii);
@@ -314,12 +324,33 @@ enum jpnevulatorRtrn jpnevulatorRead(void) {
 	int nfds;
 
 	/* Open our output file. */
-	output=ioOpen("w");
+	output=ioOpen(boolIsSet(_jpnevulatorOptions.append)?"a":"w");
 	if(output==NULL) {
 		perror(PROGRAM_NAME": Unable to open output");
 		jpnevulatorGarbageCollect();
 		return(jpnevulatorRtrnNoOutput);
 	}
+	/* In append mode we first check if the file is empty. If not we
+	   first append the given append separator. */
+	if(boolIsSet(_jpnevulatorOptions.append)) {
+		struct stat outputStat;
+		fstat(fileno(output),&outputStat);
+		if(outputStat.st_size>0) {
+			char *index;
+			/* We need to parse the append separator a little bit and search for
+			   the special newline sequence. Otherwise we simply put the found
+			   character in place. */
+			for(index=_jpnevulatorOptions.appendSeparator;*index!='\0';index++) {
+				if((*index=='\\')&&(*(index+1)=='n')) {
+					fprintf(output,"\n");
+					index++;
+				} else {
+					fprintf(output,"%c",*index);
+				}
+					
+			}
+		}
+	}
 
 	/* Allocate memory for the messages to receive. */
 	message=(unsigned char *)malloc(sizeof(message[0])*_jpnevulatorOptions.size);
@@ -457,7 +488,7 @@ enum jpnevulatorRtrn jpnevulatorRead(void) {
 								if((bytesWritten==0)&&boolIsSet(_jpnevulatorOptions.byteCountDisplay)) {
 									fprintf(output,"%08lX\t",interfaceReader->byteCount);
 								}
-								fprintf(output,"%02X",message[index]);
+								bytePut(output,_jpnevulatorOptions.base,message[index]);
 								/* Increase the byte count for this interface. */
 								interfaceReader->byteCount++;
 								if(boolIsSet(_jpnevulatorOptions.ascii)) {
