@@ -1,5 +1,5 @@
 /* jpnevulator - serial reader/writer
- * Copyright (C) 2006-2014 Freddy Spierenburg
+ * Copyright (C) 2006-2015 Freddy Spierenburg
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -30,4 +30,13 @@ typedef char bool_t;
 #define boolIsSet(x) ((x)==boolTrue)
 #define boolIsNotSet(x) ((x)==boolFalse)
 
+/* This is a nice routine to get a pointer to a string of spaces. If zero is
+ * given you will get a nice empty string. Otherwise you will get a pointer to
+ * a string of exactly the given amount of spaces. If more than the maximum
+ * amount of spaces is given, a pointer to the maximum string spaces string is
+ * returned. */
+#define __SPACES "                                                                "
+extern char __spaces[sizeof(__SPACES)];
+#define SPACES(amount) (&(__spaces[sizeof(__spaces)-min(amount,sizeof(__spaces)-1)-1]))
+
 #endif
