@@ -1,5 +1,5 @@
 /* jpnevulator - serial reader/writer
- * Copyright (C) 2006-2014 Freddy Spierenburg
+ * Copyright (C) 2006-2015 Freddy Spierenburg
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,6 +21,7 @@
 
 #include "list.h"
 #include "misc.h"
+#include "byte.h"
 
 enum checksumType {
 	checksumTypeNone=0,
@@ -58,6 +59,9 @@ struct jpnevulatorOptions {
 	bool_t control;
 	unsigned long controlPoll;
 	int count;
+	bool_t append;
+	char *appendSeparator;
+	enum byteBase base;
 };
 
 enum optionsRtrn {
