@@ -1,5 +1,5 @@
 /* jpnevulator - serial reader/writer
- * Copyright (C) 2006-2014 Freddy Spierenburg
+ * Copyright (C) 2006-2015 Freddy Spierenburg
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -28,17 +28,7 @@
 #include "tty.h"
 
 static int ttyOpen(char *name,int length) {
-	int fd;
-	struct termios options;
-	fd=open(name,O_RDWR);
-	if(fd!=-1) {
-		/* Make sure we send to a raw serial interface! */
-		fcntl(fd,F_SETFL,0);
-		tcgetattr(fd,&options);
-		cfmakeraw(&options);
-		tcsetattr(fd,TCSANOW,&options);
-	}
-	return(fd);
+	return(open(name,O_RDWR));
 }
 
 static int ttyControlGet(int fd,char *name) {
